      subroutine gray(ijetto, mr, mz, r, z, psin, psiax, psibnd,
     .    rax, zax, nbnd, rbnd, zbnd, nrho, psijet, f, te, dne,
     .    zeff, qsf, powin, dpdv, jcd, pec, icd, ierr)
c   input arguments
      integer ijetto, mr, mz, nbnd, nrho
      real*8 r(mr), z(mz), psin(mr,mz)
      real*8 psiax, psibnd, rax, zax
      real*8 rbnd(nbnd), zbnd(nbnd)
      real*8 psijet(nrho), f(nrho), qsf(nrho), te(nrho), dne(nrho)
      real*8 zeff(nrho)
c   output arguments
      real*8 dpdv(nrho), jcd(nrho), powin, pec, icd
      integer ierr
c   local variables
      real*8 fgray(nrho), qgray(nrho), jcdgry(nrho), icdgry
c
c   input arguments
c
c     ijetto  Equilibrium source (1 EFIT, 2 ESCO)
c             If IJETTO=2, then PSIN values are valid only inside
c             plasma boudary (PSIN=1 outside)
c     mr      Size of flux map grid in R direction
c     mz      Size of flux map grid in Z direction
c     r       R coordinates of flux map grid points [m]
c     z       Z coordinates of flux map grid points [m]
c     psin    Normalised poloidal flux psin=(psi-psiax)/(psibnd-psiax)
c             on the (R, Z) grid.
c     psiax   Poloidal flux on axis [Wb rad-1]
c     psibnd  Poloidal flux on boundary [Wb rad-1]
c     rax     R coordinate of magnetic axis [m]
c     zax     Z coordinate of magnetic axis [m]
c     nbnd    Number of points in plasma boundary contour
c     rbnd    R coordinates of plasma boundary contour [m]
c     zbnd    Z coordinates of plasma boundary contour [m]
c
c     nrho    Number of points in JETTO rho grid    -
c     psijet  Normalised poloidal flux on JETTO radial grid
c     f       Poloidal current stream function f=Bphi*R on JETTO
c             radial grid [T m]
c     te      Electron temperature on JETTO radial grid [eV]
c     dne     Electron density on JETTO radial grid [m-3]
c     zeff    Effective nuclear charge Zeff on JETTO radial grid
c     qsf     Safety factor on JETTO radial grid
c
c     powin   Input ECRH power [W]
c
c   output arguments
c
c     dpdv    Absorbed EC power density on JETTO radial grid [W m-3]
c     jcd     EC driven flux averaged current density on JETTO
c             radial grid [A m-2]
c     pec     Total absorbed EC power [W]
c     icd     Total EC driven current [A]
c     ierr    Return code. IERR>0 on error
c             ierr = 90-93: error computing integrals for current drive
c             ierr = 94: absorption coefficient alpha < 0
c             ierr = 97: parallel comp. refract. idx N//>0.99 (warning)
c             ierr = 98: parallel comp. refract. idx N//>1.05
c
c   JETTO coordinate system assumes toroidal angle increasing CW
c   in GRAY toroidal angle increases CCW --> adapt signs on input data
c
      do i=1,nrho
        fgray(i)=-f(i)
        qgray(i)=-qsf(i)
      end do
c
c   call main subroutine
c
      call gray_main(ijetto, mr, mz, r, z, psin, psiax, psibnd,
     .    rax, zax, nbnd, rbnd, zbnd, nrho, psijet, fgray, te, dne,
     .    zeff, qgray, powin, dpdv, jcdgry, pec, icdgry, ierr)
c
c   adapt output data to JETTO convention on toroidal angle
c
      do i=1,nrho
        jcd(i)=-jcdgry(i)
      end do
      icd=-icdgry
c
      return
      end